==> huaweicloudsdkmetastudio-3.1.142-py2.py3-none-any.whl: huaweicloudsdkmetastudio/v1/model/create_large_file_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateLargeFileResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'file_id': 'str',
        'upload_urls': 'list[str]',
        'x_request_id': 'str'
    }

    attribute_map = {
        'file_id': 'file_id',
        'upload_urls': 'upload_urls',
        'x_request_id': 'X-Request-Id'
    }

    def __init__(self, file_id=None, upload_urls=None, x_request_id=None):
        """CreateLargeFileResponse

        The model defined in huaweicloud sdk

        :param file_id: 文件ID。
        :type file_id: str
        :param upload_urls: 文件分段上传URL。
        :type upload_urls: list[str]
        :param x_request_id: 
        :type x_request_id: str
        """
        
        super(CreateLargeFileResponse, self).__init__()

        self._file_id = None
        self._upload_urls = None
        self._x_request_id = None
        self.discriminator = None

        if file_id is not None:
            self.file_id = file_id
        if upload_urls is not None:
            self.upload_urls = upload_urls
        if x_request_id is not None:
            self.x_request_id = x_request_id

    @property
    def file_id(self):
        """Gets the file_id of this CreateLargeFileResponse.

        文件ID。

        :return: The file_id of this CreateLargeFileResponse.
        :rtype: str
        """
        return self._file_id

    @file_id.setter
    def file_id(self, file_id):
        """Sets the file_id of this CreateLargeFileResponse.

        文件ID。

        :param file_id: The file_id of this CreateLargeFileResponse.
        :type file_id: str
        """
        self._file_id = file_id

    @property
    def upload_urls(self):
        """Gets the upload_urls of this CreateLargeFileResponse.

        文件分段上传URL。

        :return: The upload_urls of this CreateLargeFileResponse.
        :rtype: list[str]
        """
        return self._upload_urls

    @upload_urls.setter
    def upload_urls(self, upload_urls):
        """Sets the upload_urls of this CreateLargeFileResponse.

        文件分段上传URL。

        :param upload_urls: The upload_urls of this CreateLargeFileResponse.
        :type upload_urls: list[str]
        """
        self._upload_urls = upload_urls

    @property
    def x_request_id(self):
        """Gets the x_request_id of this CreateLargeFileResponse.

        :return: The x_request_id of this CreateLargeFileResponse.
        :rtype: str
        """
        return self._x_request_id

    @x_request_id.setter
    def x_request_id(self, x_request_id):
        """Sets the x_request_id of this CreateLargeFileResponse.

        :param x_request_id: The x_request_id of this CreateLargeFileResponse.
        :type x_request_id: str
        """
        self._x_request_id = x_request_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateLargeFileResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkmetastudio-3.1.153-py2.py3-none-any.whl: huaweicloudsdkmetastudio/v1/model/create_large_file_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateLargeFileResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'file_id': 'str',
        'upload_urls': 'list[str]',
        'x_request_id': 'str'
    }

    attribute_map = {
        'file_id': 'file_id',
        'upload_urls': 'upload_urls',
        'x_request_id': 'X-Request-Id'
    }

    def __init__(self, file_id=None, upload_urls=None, x_request_id=None):
        r"""CreateLargeFileResponse

        The model defined in huaweicloud sdk

        :param file_id: 文件ID。
        :type file_id: str
        :param upload_urls: 文件分段上传URL。
        :type upload_urls: list[str]
        :param x_request_id: 
        :type x_request_id: str
        """
        
        super(CreateLargeFileResponse, self).__init__()

        self._file_id = None
        self._upload_urls = None
        self._x_request_id = None
        self.discriminator = None

        if file_id is not None:
            self.file_id = file_id
        if upload_urls is not None:
            self.upload_urls = upload_urls
        if x_request_id is not None:
            self.x_request_id = x_request_id

    @property
    def file_id(self):
        r"""Gets the file_id of this CreateLargeFileResponse.

        文件ID。

        :return: The file_id of this CreateLargeFileResponse.
        :rtype: str
        """
        return self._file_id

    @file_id.setter
    def file_id(self, file_id):
        r"""Sets the file_id of this CreateLargeFileResponse.

        文件ID。

        :param file_id: The file_id of this CreateLargeFileResponse.
        :type file_id: str
        """
        self._file_id = file_id

    @property
    def upload_urls(self):
        r"""Gets the upload_urls of this CreateLargeFileResponse.

        文件分段上传URL。

        :return: The upload_urls of this CreateLargeFileResponse.
        :rtype: list[str]
        """
        return self._upload_urls

    @upload_urls.setter
    def upload_urls(self, upload_urls):
        r"""Sets the upload_urls of this CreateLargeFileResponse.

        文件分段上传URL。

        :param upload_urls: The upload_urls of this CreateLargeFileResponse.
        :type upload_urls: list[str]
        """
        self._upload_urls = upload_urls

    @property
    def x_request_id(self):
        r"""Gets the x_request_id of this CreateLargeFileResponse.

        :return: The x_request_id of this CreateLargeFileResponse.
        :rtype: str
        """
        return self._x_request_id

    @x_request_id.setter
    def x_request_id(self, x_request_id):
        r"""Sets the x_request_id of this CreateLargeFileResponse.

        :param x_request_id: The x_request_id of this CreateLargeFileResponse.
        :type x_request_id: str
        """
        self._x_request_id = x_request_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateLargeFileResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
